avro\_to\_python.utils.avro.types package
=========================================

Submodules
----------

avro\_to\_python.utils.avro.types.array module
----------------------------------------------

.. automodule:: avro_to_python.utils.avro.types.array
   :members:
   :undoc-members:
   :show-inheritance:

avro\_to\_python.utils.avro.types.enum module
---------------------------------------------

.. automodule:: avro_to_python.utils.avro.types.enum
   :members:
   :undoc-members:
   :show-inheritance:

avro\_to\_python.utils.avro.types.file module
---------------------------------------------

.. automodule:: avro_to_python.utils.avro.types.file
   :members:
   :undoc-members:
   :show-inheritance:

avro\_to\_python.utils.avro.types.primitive module
--------------------------------------------------

.. automodule:: avro_to_python.utils.avro.types.primitive
   :members:
   :undoc-members:
   :show-inheritance:

avro\_to\_python.utils.avro.types.record module
-----------------------------------------------

.. automodule:: avro_to_python.utils.avro.types.record
   :members:
   :undoc-members:
   :show-inheritance:

avro\_to\_python.utils.avro.types.reference module
--------------------------------------------------

.. automodule:: avro_to_python.utils.avro.types.reference
   :members:
   :undoc-members:
   :show-inheritance:

avro\_to\_python.utils.avro.types.type\_factory module
------------------------------------------------------

.. automodule:: avro_to_python.utils.avro.types.type_factory
   :members:
   :undoc-members:
   :show-inheritance:

avro\_to\_python.utils.avro.types.union module
----------------------------------------------

.. automodule:: avro_to_python.utils.avro.types.union
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: avro_to_python.utils.avro.types
   :members:
   :undoc-members:
   :show-inheritance:
